@@ -140,9 +140,6 @@ CONFIG_TRADING_SIGNALS_STRATEGY = "trading_strategy"
 # terms of service
 CONFIG_ACCEPTED_TERMS = "accepted_terms"
 
-# community
-CONFIG_COMMUNITY_TOKEN = "community-token"
-
 # metrics
 CONFIG_METRICS = "metrics"
 CONFIG_METRICS_BOT_ID = "metrics-bot-id"
